@@ -29,7 +29,7 @@ class FunctionsInfo(object):
 		f.close()
 
 	def _parameters2str(self,parameters):
-		return ','.join([k+'='+str(parameters[k]) for k in parameters])
+		return ','.join([k+'='+str(v) for k,v in parameters])
 
 	def add_function(self, function_name, parameters=[]):
 		if function_name not in self.config:
